
# Class: HasAliases




URI: [ks:HasAliases](https://w3id.org/linkml/tests/kitchen_sink/HasAliases)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Place]uses%20-.->[HasAliases&#124;aliases:string%20*],[Person]uses%20-.->[HasAliases],[Organization]uses%20-.->[HasAliases],[Place],[Person],[Organization])](https://yuml.me/diagram/nofunky;dir:TB/class/[Place]uses%20-.->[HasAliases&#124;aliases:string%20*],[Person]uses%20-.->[HasAliases],[Organization]uses%20-.->[HasAliases],[Place],[Person],[Organization])

## Mixin for

 * [Organization](Organization.md) (mixin) 
 * [Person](Person.md) (mixin) 
 * [Place](Place.md) (mixin) 

## Referenced by Class


## Attributes


### Own

 * [➞aliases](hasAliases__aliases.md)  <sub>0..\*</sub>
     * Range: [String](types/String.md)
